library material_color_gen;

import 'package:flutter/material.dart';

extension MaterialColorGenerator on Color {
  /// Generates and returns a MaterialColor from a single Color.
  ///
  /// Useful for easily conforming to [ThemeData.primarySwatch].
  MaterialColor toMaterialColor() {
    return _createMaterialColor(this);
  }

  MaterialColor _createMaterialColor(Color color) {
    List strengths = <double>[.05];
    final swatch = <int, Color>{};
    final int r = color.red, g = color.green, b = color.blue;

    for (int i = 1; i < 10; i++) {
      strengths.add(0.1 * i);
    }
    for (var strength in strengths) {
      final double ds = 0.5 - strength;
      swatch[(strength * 1000).round()] = Color.fromRGBO(
        r + ((ds < 0 ? r : (255 - r)) * ds).round(),
        g + ((ds < 0 ? g : (255 - g)) * ds).round(),
        b + ((ds < 0 ? b : (255 - b)) * ds).round(),
        1,
      );
    }
    return MaterialColor(color.value, swatch);
  }
}

